@@ -1,15 +1,15 @@
-/********************************************************************************/
-/* Copyright (c) 2004                                                           */
-/* Daniel Sleator, David Temperley, and John Lafferty                           */
-/* All rights reserved                                                          */
-/*                                                                              */
-/* Use of the link grammar parsing system is subject to the terms of the        */
-/* license set forth in the LICENSE file included with this software,           */
-/* and also available at http://www.link.cs.cmu.edu/link/license.html           */
-/* This license allows free redistribution and use in source and binary         */
-/* forms, with or without modification, subject to certain conditions.          */
-/*                                                                              */
-/********************************************************************************/
+/*************************************************************************/
+/* Copyright (c) 2004                                                    */
+/* Daniel Sleator, David Temperley, and John Lafferty                    */
+/* All rights reserved                                                   */
+/*                                                                       */
+/* Use of the link grammar parsing system is subject to the terms of the */ 
+/* license set forth in the LICENSE file included with this software,    */
+/* and also available at http://www.link.cs.cmu.edu/link/license.html    */
+/* This license allows free redistribution and use in source and binary  */
+/* forms, with or without modification, subject to certain conditions.   */
+/*                                                                       */
+/*************************************************************************/
 
 #include <link-grammar/api.h>
 
@@ -42,8 +42,11 @@ static int VDAL_compare_parse(Linkage_info * p1, Linkage_info * p2) {
 	}
 }
 
-Parse_Options parse_options_create(void) {
-	/* create and initialize a Parse_Options object */
+/** 
+ * Create and initialize a Parse_Options object
+ */
+Parse_Options parse_options_create(void)
+{
 	Parse_Options po;
 
 	po = (Parse_Options) xalloc(sizeof(struct Parse_Options_s));
@@ -318,28 +321,21 @@ void parse_options_reset_resources(Parse_Options opts) {
 *
 ****************************************************************/
 
-static int open_dictionary(char * dict_path_name, Dictionary dict)
-{
-	if ((dict->fp = dictopen(dict_path_name, dict->name, "r")) == NULL) {
-		return 0;
-	}
-	return 1;
-}
-
 /**
- * The following function is dictionary_create with an extra paramater called "path".
- * If this is non-null, then the path used to find the file is taken from that path.
- * Otherwise the path is taken from the dict_name.  This is only needed because
- * an affix_file is opened by a recursive call to this function.
+ * The following function is dictionary_create with an extra 
+ * paramater called "path". If this is non-null, then the path 
+ * used to find the file is taken from that path. Otherwise,
+ * the path is taken from the dict_name.  This is only needed 
+ * because an affix_file is opened by a recursive call to this
+ * function.
  */
-static Dictionary 
-internal_dictionary_create(char * dict_name, char * pp_name, 
-                           char * cons_name, char * affix_name, char * path)
+Dictionary 
+dictionary_create(char * dict_name, char * pp_name, 
+                  char * cons_name, char * affix_name)
 {
 	Dictionary dict;
 	static int rand_table_inited=FALSE;
 	Dict_node *dict_node;
-	char * dictionary_path_name;
 
 	dict = (Dictionary) xalloc(sizeof(struct Dictionary_s));
 
@@ -359,43 +355,29 @@ internal_dictionary_create(char * dict_name, char * pp_name,
 	dict->exp_list = NULL;
 	dict->affix_table = NULL;
 
-	/*  *DS*  remove this
-	if (pp_name != NULL) {
-		dict->post_process_filename = string_set_add(pp_name, dict->string_set);
-	}
-	else {
-		dict->post_process_filename = NULL;
-	}
-	*/
-
-	if (path != NULL) dictionary_path_name = path; else dictionary_path_name = dict_name;
-
-	if (!open_dictionary(dictionary_path_name, dict)) {
+	dict->fp = dictopen(dict->name, "r");
+	if (dict->fp == NULL) {
 		lperror(NODICT, dict_name);
-		string_set_delete(dict->string_set);
-		xfree(dict, sizeof(struct Dictionary_s));
-		return NULL;
+		goto failure;
 	}
 
 	if (!read_dictionary(dict)) {
-		string_set_delete(dict->string_set);
-		xfree(dict, sizeof(struct Dictionary_s));
-		return NULL;
+		goto failure;
+	}
+
+	dict->affix_table = NULL;
+	if (affix_name != NULL) {
+		dict->affix_table = dictionary_create(affix_name, NULL, NULL, NULL);
+		if (dict->affix_table == NULL) {
+			fprintf(stderr, "%s\n", lperrmsg);
+			goto failure;
+		}
 	}
 
 	dict->left_wall_defined  = boolean_dictionary_lookup(dict, LEFT_WALL_WORD);
 	dict->right_wall_defined = boolean_dictionary_lookup(dict, RIGHT_WALL_WORD);
-	dict->postprocessor	  = post_process_open(dict->name, pp_name);
-	dict->constituent_pp	 = post_process_open(dict->name, cons_name);
-
-	dict->affix_table = NULL;
-	if (affix_name != NULL) {
-		dict->affix_table = internal_dictionary_create(affix_name, NULL, NULL, NULL, dict_name);
-		if (dict->affix_table == NULL) {
-			fprintf(stderr, "%s\n", lperrmsg);
-			exit(-1);
-		}
-	}
+	dict->postprocessor	  = post_process_open(pp_name);
+	dict->constituent_pp	 = post_process_open(cons_name);
 
 	dict->unknown_word_defined = boolean_dictionary_lookup(dict, UNKNOWN_WORD);
 	dict->use_unknown_word = TRUE;
@@ -424,11 +406,11 @@ internal_dictionary_create(char * dict_name, char * pp_name,
 	free_lookup_list(dict_node);
 
 	return dict;
-}
 
-Dictionary dictionary_create(char * dict_name, char * pp_name, char * cons_name, char * affix_name) 
-{
-	return internal_dictionary_create(dict_name, pp_name, cons_name, affix_name, NULL);
+failure:
+	string_set_delete(dict->string_set);
+	xfree(dict, sizeof(struct Dictionary_s));
+	return NULL;
 }
 
 Dictionary dictionary_create_lang(char * lang)
@@ -595,7 +577,9 @@ static void free_andlists(Sentence sent)
 	/* printf("\n"); */
 }
 
-int sentence_length(Sentence sent) {
+int sentence_length(Sentence sent)
+{
+	if (!sent) return 0;
 	return sent->length;
 }
 
