@@ -19,7 +19,7 @@
    a time, we keep around a pointer to the end of string to prevent
    the algorithm from being quadratic. */
 
-String * String_create() {
+String * String_create(void) {
     String * string;
     string = (String *) exalloc(sizeof(String));
     string->allocated = 1;
@@ -29,7 +29,7 @@ String * String_create() {
     return string;
 }
 
-int append_string(String * string, char *fmt, ...) {
+int append_string(String * string, const char *fmt, ...) {
     char temp_string[1024];
     char * p;
     int new_size;
