@@ -287,14 +287,8 @@ static char * get_datadir(void)
  * for the file in a sequence of directories until it finds it.  The
  * sequence of directories is specified in a dictpath string, in
  * which each directory is followed by a ":".
- *
- * The dictpath that it uses is constructed as follows.  If the
- * dictname is non-null, and is an absolute path name (beginning
- * with a "/", then the part after the last "/" is removed and this
- * is the first directory on the dictpath.  After this comes the
- * DICTPATH environment variable, followed by the DEFAULTPATH
  */
-FILE *dictopen(const char *dictname, const char *filename, const char *how)
+FILE *dictopen(const char *filename, const char *how)
 {
 	char completename[MAX_PATH_NAME+1];
 	char fulldictpath[MAX_PATH_NAME+1];
@@ -303,20 +297,24 @@ FILE *dictopen(const char *dictname, const char *filename, const char *how)
 	FILE *fp;
 
 	if (filename[0] == '/') {
-		fp = fopen(filename, how);  /* If the file does not exist NULL is returned */
+		/* fopen returns NULL if the file does not exist. */
+		fp = fopen(filename, how);
 		if(fp) return fp;
 	}
 
 	{
 		char * data_dir = get_datadir();
 		if (data_dir) {
-			sprintf(fulldictpath, "%s%c%s%c", data_dir, PATH_SEPARATOR, DEFAULTPATH, PATH_SEPARATOR);
+			snprintf(fulldictpath, MAX_PATH_NAME, 
+			         "%s%c%s%c", data_dir, PATH_SEPARATOR, 
+			                    DEFAULTPATH, PATH_SEPARATOR);
 			free(data_dir);
 		}
 		else {
 			/* always make sure that it ends with a path separator char
 			 * for the below while() loop. */
-			sprintf(fulldictpath, "%s%c", DEFAULTPATH, PATH_SEPARATOR);
+			snprintf(fulldictpath, MAX_PATH_NAME,
+			         "%s%c", DEFAULTPATH, PATH_SEPARATOR);
 		}
 	}
 
